Index: tools/testing/dart/drt_updater.dart |
diff --git a/tools/testing/dart/drt_updater.dart b/tools/testing/dart/drt_updater.dart |
index 67e1716c454f2be77497ffa994bf79b8e6c3c6e5..7a0c9c92490b7651df30225c76c3eae9bcee6be8 100644 |
--- a/tools/testing/dart/drt_updater.dart |
+++ b/tools/testing/dart/drt_updater.dart |
@@ -60,18 +60,18 @@ class _DartiumUpdater { |
} |
} |
-_DartiumUpdater _dumpRenderTreeUpdater; |
+_DartiumUpdater _contentShellUpdater; |
_DartiumUpdater _dartiumUpdater; |
_DartiumUpdater runtimeUpdater(Map configuration) { |
String runtime = configuration['runtime']; |
if (runtime == 'drt' && configuration['drt'] == '') { |
- // Download the default DumpRenderTree from Google Storage. |
- if (_dumpRenderTreeUpdater == null) { |
- _dumpRenderTreeUpdater = new _DartiumUpdater('DumpRenderTree', |
- 'get_archive.py', 'drt'); |
+ // Download the default content shell from Google Storage. |
+ if (_contentShellUpdater == null) { |
+ _contentShellUpdater = new _DartiumUpdater('Content Shell', |
+ 'get_archive.py', 'drt'); |
} |
- return _dumpRenderTreeUpdater; |
+ return _contentShellUpdater; |
} else if (runtime == 'dartium' && configuration['dartium'] == '') { |
// Download the default Dartium from Google Storage. |
if (_dartiumUpdater == null) { |